@@ -2,7 +2,7 @@
 
 /*  $Id$
  *
- *  Copyright (c) 2006 Nick Schermer <nick@xfce.org>
+ *  Copyright © 2005 Nick Schermer <nickschermer@gmail.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,11 +22,13 @@
 #ifndef CLIPMAN_DIALOGS_H
 #define CLIPMAN_DIALOGS_H
 
-G_BEGIN_DECLS
-
 void
 clipman_configure (XfcePanelPlugin *plugin, ClipmanPlugin *clipman);
 
-G_END_DECLS
+void
+clipman_about (XfcePanelPlugin *plugin);
+
+void
+clipman_question (ClipmanAction *action);
 
 #endif
